@@ -1,6 +1,6 @@
 ### This file is part of 'germinationmetrics' package for R.
 
-### Copyright (C) 2017-2022, ICAR-NBPGR.
+### Copyright (C) 2017-2023, ICAR-NBPGR.
 #
 # germinationmetrics is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -119,6 +119,13 @@ GermPercent <- function(germinated.seeds, germ.counts, total.seeds,
       stop("'partial' should be a logical vector of length 1.")
     }
 
+    # Check if data is cumulative
+    if (!partial) {
+      if(is.unsorted(germ.counts)) {
+        stop("'germ.counts' is not cumulative.")
+      }
+    }
+
     # Convert cumulative to partial
     if (!partial) {
       germ.counts <- c(germ.counts[1], diff(germ.counts))
@@ -159,6 +166,13 @@ PeakGermPercent <- function(germ.counts, intervals, total.seeds,
     stop("'partial' should be a logical vector of length 1.")
   }
 
+  # Check if data is cumulative
+  if (!partial) {
+    if(is.unsorted(germ.counts)) {
+      stop("'germ.counts' is not cumulative.")
+    }
+  }
+
   # Convert cumulative to partial
   if (!partial) {
     germ.counts <- c(germ.counts[1], diff(germ.counts))
