@@ -1,6 +1,6 @@
 ### This file is part of 'germinationmetrics' package for R.
 
-### Copyright (C) 2017-2022, ICAR-NBPGR.
+### Copyright (C) 2017-2023, ICAR-NBPGR.
 #
 # germinationmetrics is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 #' Timson's index
 #'
 #' Compute George's index
-#' \insertCite{george_influence_1961,tucker_estimating_1965,nichols_two_1968,chopraEffectSoilTemperature1980}{germinationmetrics},
+#' \insertCite{george_influence_1961,tucker_estimating_1965,nichols_two_1968,chopra_effect_1980}{germinationmetrics},
 #' Timson's index or Timson's germination velocity index
-#' \insertCite{grose_laboratory_1958,timson_new_1965,lyonRapidMethodDetermining1966,chaudharyEffectTemperatureAssociated1970,negm_effects_1978,brown_representing_1988,baskin_seeds_1998}{germinationmetrics}
+#' \insertCite{grose_laboratory_1958,timson_new_1965,lyon_rapid_1966,chaudhary_effect_1970,negm_effects_1978,brown_representing_1988,baskin_seeds_1998}{germinationmetrics}
 #' and it's modifications by Labouriau
 #' \insertCite{ranal_how_2006}{germinationmetrics} and
 #' \insertCite{khan_effect_1984}{germinationmetrics}. \loadmathjax
@@ -50,10 +50,10 @@
 #' total percentage of germination and estimates the area under the cumulative
 #' germination percentage curve. It is same as the indices for area under time
 #' course curve of germination described by
-#' \insertCite{lyonRapidMethodDetermining1966;textual}{germinationmetrics} as
+#' \insertCite{lyon_rapid_1966;textual}{germinationmetrics} as
 #' well as \insertCite{negm_effects_1978;textual}{germinationmetrics}. It is
 #' also described as Emergence Rate Index (\mjseqn{ERI}) by
-#' \insertCite{chaudharyEffectTemperatureAssociated1970;textual}{germinationmetrics}.
+#' \insertCite{chaudhary_effect_1970;textual}{germinationmetrics}.
 #'
 #' \insertCite{goodchild_method_1971;textual}{germinationmetrics}, described the
 #' same in terms of partial germination percentage as follows.
@@ -98,7 +98,7 @@
 #'
 #' This index uses number of seeds germinated instead of germination percentage.
 #' It is also described as Emergence Rate Index (\mjseqn{ERI}) by
-#' \insertCite{chopraEffectSoilTemperature1980;textual}{germinationmetrics}.
+#' \insertCite{chopra_effect_1980;textual}{germinationmetrics}.
 #'
 #' So germination rate (\mjseqn{GR}) can also be described in terms of partial
 #' (\mjseqn{N_{i}}) and cumulative (\mjseqn{\sum_{j=1}^{i}N_{j}}) number of
@@ -137,7 +137,7 @@
 #'
 #' # From partial germination counts
 #' #----------------------------------------------------------------------------
-#' # Wihout max specified
+#' # Without max specified
 #' TimsonsIndex(germ.counts = x, intervals = int, total.seeds = 50)
 #' TimsonsIndex(germ.counts = x, intervals = int, total.seeds = 50,
 #'              modification = "none")
@@ -161,7 +161,7 @@
 #'
 #' # From cumulative germination counts
 #' #----------------------------------------------------------------------------
-#' # Wihout max specified
+#' # Without max specified
 #' TimsonsIndex(germ.counts = y, intervals = int, partial = FALSE,
 #'              total.seeds = 50)
 #' TimsonsIndex(germ.counts = y, intervals = int, partial = FALSE,
@@ -173,7 +173,7 @@
 #' TimsonsIndex(germ.counts = y, intervals = int, partial = FALSE,
 #'              total.seeds = 50,
 #'              modification = "khanungar")
-#' GermRateGeorge(germ.counts = y, intervals = int, partial = FALSE,)
+#' GermRateGeorge(germ.counts = y, intervals = int, partial = FALSE)
 #'
 #' # With max specified
 #' TimsonsIndex(germ.counts = y, intervals = int, partial = FALSE,
@@ -229,6 +229,13 @@ TimsonsIndex <- function(germ.counts, intervals, partial = TRUE,
     stop("'partial' should be a logical vector of length 1.")
   }
 
+  # Check if data is cumulative
+  if (!partial) {
+    if(is.unsorted(germ.counts)) {
+      stop("'germ.counts' is not cumulative.")
+    }
+  }
+
   # Convert cumulative to partial
   if (!partial) {
     germ.counts <- c(germ.counts[1], diff(germ.counts))
@@ -310,6 +317,13 @@ GermRateGeorge <- function(germ.counts, intervals, partial = TRUE, max) {
     stop("'partial' should be a logical vector of length 1.")
   }
 
+  # Check if data is cumulative
+  if (!partial) {
+    if(is.unsorted(germ.counts)) {
+      stop("'germ.counts' is not cumulative.")
+    }
+  }
+
   # Convert cumulative to partial
   if (!partial) {
     germ.counts <- c(germ.counts[1], diff(germ.counts))
